@@ -27,10 +27,10 @@ Created on Nov 10, 2010
 
 from pyocci import registry, service
 from pyocci.examples.vm_skeleton import Compute, Network, IPNetworking, Storage, \
-    NetworkInterface, StorageLink
+    NetworkInterface, StorageLink, IPNetworkingLink
 from pyocci.rendering_parsers import TextPlainRendering, TextHeaderRendering, \
     TextHTMLRendering, URIListRendering
-from pyocci.service import ResourceHandler, ListHandler, QueryHandler, \
+from pyocci.service import ResourceHandler, CollectionHandler, QueryHandler, \
     LogoutHandler, LoginHandler
 import tornado.httpserver
 import tornado.web
@@ -63,7 +63,7 @@ class MyService():
             (r"/-/", QueryHandler),
             (r"/login", Login),
             (r"/logout", LogoutHandler),
-            (r"/(.*)/", ListHandler),
+            (r"/(.*)/", CollectionHandler),
             (r"(.*)", ResourceHandler),
         ], **settings)
 
@@ -111,6 +111,7 @@ if __name__ == '__main__':
                                   Storage())
         registry.register_backend([NetworkInterface.kind], NetworkInterface())
         registry.register_backend([StorageLink.kind], StorageLink())
+        registry.register_backend([IPNetworkingLink.kind], IPNetworkingLink())
 
     except:
         pass
